# CMeel LAPACK

[![PyPI version](https://badge.fury.io/py/cmeel-lapack.svg)](https://pypi.org/project/cmeel-lapack)
[![Release](https://github.com/cmake-wheel/cmeel-lapack/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-lapack/actions/workflows/release.yml)

[LAPACK](https://netlib.org/lapack/) distribution for cmeel packages.
